--- channels/chan_dahdi.c.orig	2009-04-17 11:28:45.000000000 -0300
+++ channels/chan_dahdi.c	2009-04-23 04:36:19.000000000 -0300
@@ -225,6 +225,10 @@
 
 static char defaultcic[64] = "";
 static char defaultozz[64] = "";
+static char feat_callwaitingdisable[10] = ""; /* Default is *70 */
+static char feat_cancallforwardon[10] = ""; /* Default is *72 */
+static char feat_cancallforwardoff[10] = ""; /* Default is *73 */
+static char feat_donotdisturb[10] = ""; /* Default is *79 */
 
 static char parkinglot[AST_MAX_EXTENSION] = "";		/*!< Default parking lot for this channel */
 
@@ -6951,7 +6955,7 @@
 				dahdi_wait_event(p->subs[idx].dfd);
 				ast_hangup(chan);
 				goto quit;
-			} else if (p->callwaiting && !strcmp(exten, "*70")) {
+			} else if (p->callwaiting && !strcmp(exten, feat_callwaitingdisable)) {
 				ast_verb(3, "Disabling call waiting on %s\n", chan->name);
 				/* Disable call waiting if enabled */
 				p->callwaiting = 0;
@@ -7026,19 +7030,19 @@
 				getforward = 0;
 				memset(exten, 0, sizeof(exten));
 				len = 0;
-			} else if (!strcmp(exten, "*79")) {
+			} else if (!strcmp(exten, feat_donotdisturb)) {
 				dahdi_dnd(p, 0);
 				/* Do not disturb */
 				res = tone_zone_play_tone(p->subs[idx].dfd, DAHDI_TONE_DIALRECALL);
 				getforward = 0;
 				memset(exten, 0, sizeof(exten));
 				len = 0;
-			} else if (p->cancallforward && !strcmp(exten, "*72")) {
+			} else if (p->cancallforward && !strcmp(exten, feat_cancallforwardon)) {
 				res = tone_zone_play_tone(p->subs[idx].dfd, DAHDI_TONE_DIALRECALL);
 				getforward = 1;
 				memset(exten, 0, sizeof(exten));
 				len = 0;
-			} else if (p->cancallforward && !strcmp(exten, "*73")) {
+			} else if (p->cancallforward && !strcmp(exten, feat_cancallforwardoff)) {
 				ast_verb(3, "Cancelling call forwarding on channel %d\n", p->channel);
 				res = tone_zone_play_tone(p->subs[idx].dfd, DAHDI_TONE_DIALRECALL);
 				memset(p->call_forward, 0, sizeof(p->call_forward));
@@ -14987,6 +14991,14 @@
 				ast_copy_string(defaultozz, v->value, sizeof(defaultozz));
 			} else if (!strcasecmp(v->name, "mwilevel")) {
 				mwilevel = atoi(v->value);
+			} else if (!strcasecmp(v->name, "feat_callwaitingdisable")) {
+				ast_copy_string(feat_callwaitingdisable, v->value, sizeof(feat_callwaitingdisable));
+			} else if (!strcasecmp(v->name, "feat_cancallforwardon")) {
+				ast_copy_string(feat_cancallforwardon, v->value, sizeof(feat_cancallforwardon));
+			} else if (!strcasecmp(v->name, "feat_cancallforwardoff")) {
+				ast_copy_string(feat_cancallforwardoff, v->value, sizeof(feat_cancallforwardoff));
+			} else if (!strcasecmp(v->name, "feat_donotdisturb")) {
+				ast_copy_string(feat_donotdisturb, v->value, sizeof(feat_donotdisturb));
 			}
 		} else if (!(options & PROC_DAHDI_OPT_NOWARN) )
 			ast_log(LOG_WARNING, "Ignoring any changes to '%s' (on reload) at line %d.\n", v->name, v->lineno);
@@ -15216,6 +15228,19 @@
 #endif
 	/* And start the monitor for the first time */
 	restart_monitor();
+	/* Setup default features */
+	if(strcmp(feat_callwaitingdisable,"")==0) {
+		strcpy(feat_callwaitingdisable,"*70");	
+	}
+	if(strcmp(feat_cancallforwardon,"")==0) {
+		strcpy(feat_cancallforwardon,"*72");	
+	}
+	if(strcmp(feat_cancallforwardoff,"")==0) {
+		strcpy(feat_cancallforwardoff,"*73");	
+	}
+	if(strcmp(feat_donotdisturb,"")==0) {
+		strcpy(feat_cancallforwardoff,"*79");	
+	}
 	return 0;
 }
 
